svn commit: r266006 - head/sys/modules/sound/driver/uaudio

2014-05-14 Thread Hans Petter Selasky
Author: hselasky
Date: Wed May 14 07:33:06 2014
New Revision: 266006
URL: http://svnweb.freebsd.org/changeset/base/266006

Log:
  Change the USB audio kernel module linking order, so that the USB
  audio device driver is detached first and not its children. This fixes
  a panic in some cases when unloading "snd_uaudio" while a USB device
  is plugged. The linking order affects the order in which the module
  dependencies are registered.
  
  MFC after:1 week

Modified:
  head/sys/modules/sound/driver/uaudio/Makefile

Modified: head/sys/modules/sound/driver/uaudio/Makefile
==
--- head/sys/modules/sound/driver/uaudio/Makefile   Wed May 14 04:57:55 
2014(r266005)
+++ head/sys/modules/sound/driver/uaudio/Makefile   Wed May 14 07:33:06 
2014(r266006)
@@ -7,6 +7,6 @@ S=  ${.CURDIR}/../../../..
 KMOD=  snd_uaudio
 SRCS=  bus_if.h device_if.h usb_if.h vnode_if.h
 SRCS+= opt_usb.h opt_bus.h feeder_if.h channel_if.h usbdevs.h
-SRCS+= uaudio.c uaudio_pcm.c
+SRCS+= uaudio_pcm.c uaudio.c 
 
 .include 
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


Re: svn commit: r266006 - head/sys/modules/sound/driver/uaudio

2014-05-14 Thread Marius Strobl
On Wed, May 14, 2014 at 07:33:06AM +, Hans Petter Selasky wrote:
> Author: hselasky
> Date: Wed May 14 07:33:06 2014
> New Revision: 266006
> URL: http://svnweb.freebsd.org/changeset/base/266006
> 
> Log:
>   Change the USB audio kernel module linking order, so that the USB
>   audio device driver is detached first and not its children. This fixes
>   a panic in some cases when unloading "snd_uaudio" while a USB device
>   is plugged. The linking order affects the order in which the module
>   dependencies are registered.

The right way of specifying that uaudio should be registered last, i. e.
after other device drivers employing DRIVER_MODULE(), would be using:
DRIVER_MODULE_ORDER(uaudio, uhub, uaudio_driver, uaudio_devclass, NULL, NULL,
SI_ORDER_ANY);
instead of the existing DRIVER_MODULE() in uaudio.c.

Marius

___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r266007 - head/sys/kern

2014-05-14 Thread Edward Tomasz Napierala
Author: trasz
Date: Wed May 14 09:03:02 2014
New Revision: 266007
URL: http://svnweb.freebsd.org/changeset/base/266007

Log:
  Initialize loginclass mutex using MTX_SYSINIT instead of using SI_SUB_CPU.
  
  Suggested by: rwatson@
  MFC after:1 month
  Sponsored by: The FreeBSD Foundation

Modified:
  head/sys/kern/kern_loginclass.c

Modified: head/sys/kern/kern_loginclass.c
==
--- head/sys/kern/kern_loginclass.c Wed May 14 07:33:06 2014
(r266006)
+++ head/sys/kern/kern_loginclass.c Wed May 14 09:03:02 2014
(r266007)
@@ -69,9 +69,7 @@ LIST_HEAD(, loginclass)   loginclasses;
  * Lock protecting loginclasses list.
  */
 static struct mtx loginclasses_lock;
-
-static void lc_init(void);
-SYSINIT(loginclass, SI_SUB_CPU, SI_ORDER_FIRST, lc_init, NULL);
+MTX_SYSINIT(loginclasses_init, &loginclasses_lock, "loginclasses lock", 
MTX_DEF);
 
 void
 loginclass_hold(struct loginclass *lc)
@@ -229,10 +227,3 @@ loginclass_racct_foreach(void (*callback
(callback)(lc->lc_racct, arg2, arg3);
mtx_unlock(&loginclasses_lock);
 }
-
-static void
-lc_init(void)
-{
-
-   mtx_init(&loginclasses_lock, "loginclasses lock", NULL, MTX_DEF);
-}
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


Re: svn commit: r265358 - head/sys/dev/usb/controller

2014-05-14 Thread Ganbold Tsagaankhuu
Hans

On Mon, May 5, 2014 at 7:50 PM, Hans Petter Selasky wrote:

> Author: hselasky
> Date: Mon May  5 11:50:52 2014
> New Revision: 265358
> URL: http://svnweb.freebsd.org/changeset/base/265358
>
> Log:
>   Improve DWC OTG USB host side support for isochronous FULL and HIGH
>   speed data traffic going directly to a USB device or through a
>   so-called USB transaction translator.
>
>   Add checks that we are not overusing the TX FIFO.
>
>   MFC after:2 weeks
>
> Modified:
>   head/sys/dev/usb/controller/dwc_otg.c
>   head/sys/dev/usb/controller/dwc_otg.h
>   head/sys/dev/usb/controller/dwc_otgreg.h
>
> Modified: head/sys/dev/usb/controller/dwc_otg.c
>
> ==
> --- head/sys/dev/usb/controller/dwc_otg.c   Mon May  5 11:30:45 2014
>  (r265357)
> +++ head/sys/dev/usb/controller/dwc_otg.c   Mon May  5 11:50:52 2014
>  (r265358)
> @@ -207,6 +207,12 @@ dwc_otg_init_fifo(struct dwc_otg_softc *
> /* reset active endpoints */
> sc->sc_active_rx_ep = 0;
>
> +   /* reset TX size */
> +   sc->sc_tx_cur_size = 0;
> +
> +   /* reset TT info */
> +   memset(sc->sc_tt_info, 0, sizeof(sc->sc_tt_info));
> +
> fifo_size /= 2;
>
> DWC_OTG_WRITE_4(sc, DOTG_GNPTXFSIZ,
> @@ -215,19 +221,17 @@ dwc_otg_init_fifo(struct dwc_otg_softc *
>
> tx_start += fifo_size;
>
> +   for (x = 0; x != sc->sc_host_ch_max; x++) {
> +   /* enable all needed interrupts */
> +   DWC_OTG_WRITE_4(sc, DOTG_HCINTMSK(x),
> HCINT_DEFAULT_MASK);
> +   }
> +
> DWC_OTG_WRITE_4(sc, DOTG_HPTXFSIZ,
> ((fifo_size / 4) << 16) |
> (tx_start / 4));
>
> -   for (x = 0; x != sc->sc_host_ch_max; x++) {
> -   /* enable interrupts */
> -   DWC_OTG_WRITE_4(sc, DOTG_HCINTMSK(x),
> -   HCINT_STALL | HCINT_BBLERR |
> -   HCINT_XACTERR |
> -   HCINT_NAK | HCINT_ACK | HCINT_NYET |
> -   HCINT_CHHLTD | HCINT_FRMOVRUN |
> -   HCINT_DATATGLERR);
> -   }
> +   /* store maximum TX FIFO size */
> +   sc->sc_tx_max_size = fifo_size;
>
> /* enable host channel interrupts */
> DWC_OTG_WRITE_4(sc, DOTG_HAINTMSK,
> @@ -309,6 +313,12 @@ dwc_otg_init_fifo(struct dwc_otg_softc *
> } else {
> /* reset active endpoints */
> sc->sc_active_rx_ep = 0;
> +
> +   /* reset TX size */
> +   sc->sc_tx_cur_size = 0;
> +
> +   /* reset TT info */
> +   memset(sc->sc_tt_info, 0, sizeof(sc->sc_tt_info));
> }
> return (0);
>  }
> @@ -376,9 +386,9 @@ dwc_otg_pull_down(struct dwc_otg_softc *
>  static void
>  dwc_otg_enable_sof_irq(struct dwc_otg_softc *sc)
>  {
> -   if (sc->sc_irq_mask & GINTSTS_SOF)
> +   if (sc->sc_irq_mask & GINTMSK_SOFMSK)
> return;
> -   sc->sc_irq_mask |= GINTSTS_SOF;
> +   sc->sc_irq_mask |= GINTMSK_SOFMSK;
> DWC_OTG_WRITE_4(sc, DOTG_GINTMSK, sc->sc_irq_mask);
>  }
>
> @@ -506,6 +516,7 @@ dwc_otg_clear_hcint(struct dwc_otg_softc
>  {
> uint32_t hcint;
>
> +   /* clear all pending interrupts */
> hcint = DWC_OTG_READ_4(sc, DOTG_HCINT(x));
> DWC_OTG_WRITE_4(sc, DOTG_HCINT(x), hcint);
>
> @@ -513,6 +524,10 @@ dwc_otg_clear_hcint(struct dwc_otg_softc
> sc->sc_chan_state[x].hcint = 0;
>  }
>
> +/*
> + * This function waits until a DWC OTG host channel is ready to be
> + * used again:
> + */
>  static uint8_t
>  dwc_otg_host_channel_wait(struct dwc_otg_td *td)
>  {
> @@ -545,6 +560,9 @@ dwc_otg_host_channel_wait(struct dwc_otg
> sc->sc_chan_state[td->channel].allocated = 0;
> sc->sc_chan_state[x].allocated = 1;
>
> +   sc->sc_chan_state[x].tx_size =
> +   sc->sc_chan_state[td->channel].tx_size;
> +
> if (sc->sc_chan_state[td->channel].suspended) {
> sc->sc_chan_state[td->channel].suspended = 0;
> sc->sc_chan_state[x].suspended = 1;
> @@ -579,6 +597,7 @@ static uint8_t
>  dwc_otg_host_channel_alloc(struct dwc_otg_td *td)
>  {
> struct dwc_otg_softc *sc;
> +   uint32_t tx_size;
> uint8_t x;
> uint8_t max_channel;
>
> @@ -591,9 +610,25 @@ dwc_otg_host_channel_alloc(struct dwc_ot
> if ((td->hcchar & HCCHAR_EPNUM_MASK) == 0) {
> max_channel = 1;
> x = 0;
> +   tx_size = td->max_packet_size;
> +   if ((sc->sc_tx_cur_size + tx_size) > sc->sc_tx_max_size) {
> +   DPRINTF("Too little FIFO space\n");
> +  

svn commit: r266010 - head/sys/arm/broadcom/bcm2835

2014-05-14 Thread Aleksandr Rybalko
Author: ray
Date: Wed May 14 11:15:48 2014
New Revision: 266010
URL: http://svnweb.freebsd.org/changeset/base/266010

Log:
  Remove extra newlines.
  No functional changes.
  
  Sponsored by: The FreeBSD Foundation

Modified:
  head/sys/arm/broadcom/bcm2835/bcm2835_fbd.c

Modified: head/sys/arm/broadcom/bcm2835/bcm2835_fbd.c
==
--- head/sys/arm/broadcom/bcm2835/bcm2835_fbd.c Wed May 14 09:13:33 2014
(r266009)
+++ head/sys/arm/broadcom/bcm2835/bcm2835_fbd.c Wed May 14 11:15:48 2014
(r266010)
@@ -99,7 +99,6 @@ struct bcmsc_softc {
struct bcm_fb_config*   fb_config;
bus_addr_t  fb_config_phys;
struct intr_config_hook init_hook;
-
 };
 
 static int bcm_fb_probe(device_t);
@@ -167,14 +166,10 @@ bcm_fb_init(void *arg)
fb_config->xoffset, fb_config->yoffset,
fb_config->bpp);
 
-
device_printf(sc->dev, "pitch %d, base 0x%08x, screen_size 
%d\n",
fb_config->pitch, fb_config->base,
fb_config->screen_size);
 
-
-
-
info = malloc(sizeof(struct fb_info), M_DEVBUF,
M_WAITOK | M_ZERO);
info->fb_name = device_get_nameunit(sc->dev);
@@ -199,8 +194,6 @@ bcm_fb_init(void *arg)
device_printf(sc->dev, "Failed to attach fbd device\n");
return;
}
-
-
} else {
device_printf(sc->dev, "Failed to set framebuffer info\n");
return;
@@ -273,7 +266,6 @@ fail:
return (ENXIO);
 }
 
-
 static void
 bcm_fb_dmamap_cb(void *arg, bus_dma_segment_t *segs, int nseg, int err)
 {
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r266011 - head/sys/dev/sound/usb

2014-05-14 Thread Hans Petter Selasky
Author: hselasky
Date: Wed May 14 11:25:59 2014
New Revision: 266011
URL: http://svnweb.freebsd.org/changeset/base/266011

Log:
  Make sure the USB audio driver is loaded last. This is important when
  built as part of a kernel module to prevent panics when the USB audio
  driver kernel module is unloaded.
  
  Suggested by: marius @
  MFC after:1 week

Modified:
  head/sys/dev/sound/usb/uaudio.c

Modified: head/sys/dev/sound/usb/uaudio.c
==
--- head/sys/dev/sound/usb/uaudio.c Wed May 14 11:15:48 2014
(r266010)
+++ head/sys/dev/sound/usb/uaudio.c Wed May 14 11:25:59 2014
(r266011)
@@ -5917,7 +5917,7 @@ uaudio_hid_detach(struct uaudio_softc *s
usbd_transfer_unsetup(sc->sc_hid.xfer, UAUDIO_HID_N_TRANSFER);
 }
 
-DRIVER_MODULE(uaudio, uhub, uaudio_driver, uaudio_devclass, NULL, 0);
+DRIVER_MODULE_ORDERED(uaudio, uhub, uaudio_driver, uaudio_devclass, NULL, 0, 
SI_ORDER_ANY);
 MODULE_DEPEND(uaudio, usb, 1, 1, 1);
 MODULE_DEPEND(uaudio, sound, SOUND_MINVER, SOUND_PREFVER, SOUND_MAXVER);
 MODULE_VERSION(uaudio, 1);
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r266012 - head/sys/dev/usb/controller

2014-05-14 Thread Hans Petter Selasky
Author: hselasky
Date: Wed May 14 11:32:15 2014
New Revision: 266012
URL: http://svnweb.freebsd.org/changeset/base/266012

Log:
  Disable configuration of the host frame interval register until
  further, hence it breaks USB support on some non-RPI platforms.

Modified:
  head/sys/dev/usb/controller/dwc_otg.c

Modified: head/sys/dev/usb/controller/dwc_otg.c
==
--- head/sys/dev/usb/controller/dwc_otg.c   Wed May 14 11:25:59 2014
(r266011)
+++ head/sys/dev/usb/controller/dwc_otg.c   Wed May 14 11:32:15 2014
(r266012)
@@ -350,6 +350,12 @@ dwc_otg_init_fifo(struct dwc_otg_softc *
 static void
 dwc_otg_update_host_frame_interval(struct dwc_otg_softc *sc)
 {
+
+  /*
+   * Disabled until further. Assuming that the register is already
+   * programmed correctly by the boot loader.
+   */
+#if 0
uint32_t temp;
 
/* setup HOST frame interval register, based on existing value */
@@ -375,6 +381,7 @@ dwc_otg_update_host_frame_interval(struc
DPRINTF("HFIR=0x%08x\n", temp);
 
DWC_OTG_WRITE_4(sc, DOTG_HFIR, temp);
+#endif
 }
 
 static void
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


Re: svn commit: r265358 - head/sys/dev/usb/controller

2014-05-14 Thread Hans Petter Selasky

Hi,

See:

http://svnweb.freebsd.org/changeset/base/266012

Sorry, I cannot test all platforms currently because some configuration 
is specific to each hardware platform.


--HPS
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r266021 - head/sys/arm/freescale/vybrid

2014-05-14 Thread Ruslan Bukin
Author: br
Date: Wed May 14 14:19:57 2014
New Revision: 266021
URL: http://svnweb.freebsd.org/changeset/base/266021

Log:
  Fix typo.

Modified:
  head/sys/arm/freescale/vybrid/vf_port.c

Modified: head/sys/arm/freescale/vybrid/vf_port.c
==
--- head/sys/arm/freescale/vybrid/vf_port.c Wed May 14 14:17:51 2014
(r266020)
+++ head/sys/arm/freescale/vybrid/vf_port.c Wed May 14 14:19:57 2014
(r266021)
@@ -165,7 +165,7 @@ port_setup(int pnum, enum ev_type pevt, 
val = PCR_INT_FE;
break;
case INT_EITHER_EDGE:
-   val = PCR_INT_RE;
+   val = PCR_INT_EE;
break;
case INT_LOGIC_ONE:
val = PCR_INT_LO;
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r266033 - head/release/doc/en_US.ISO8859-1/relnotes

2014-05-14 Thread Glen Barber
Author: gjb
Date: Wed May 14 15:31:18 2014
New Revision: 266033
URL: http://svnweb.freebsd.org/changeset/base/266033

Log:
  Document r265995, Blowfish crypt(3) format change.
  
  Sponsored by: The FreeBSD Foundation

Modified:
  head/release/doc/en_US.ISO8859-1/relnotes/article.xml

Modified: head/release/doc/en_US.ISO8859-1/relnotes/article.xml
==
--- head/release/doc/en_US.ISO8859-1/relnotes/article.xml   Wed May 14 
15:31:16 2014(r266032)
+++ head/release/doc/en_US.ISO8859-1/relnotes/article.xml   Wed May 14 
15:31:18 2014(r266033)
@@ -311,6 +311,10 @@
   to filter by &man.jail.8; ID or name, in followup to the
   &man.ps.1; change in r265229.
 
+The Blowfish &man.crypt.3; default format
+  has been changed tox
+  $2b$.
+
 
   /etc/rc.d Scripts
 
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r266032 - head/release/doc/en_US.ISO8859-1/relnotes

2014-05-14 Thread Glen Barber
Author: gjb
Date: Wed May 14 15:31:16 2014
New Revision: 266032
URL: http://svnweb.freebsd.org/changeset/base/266032

Log:
  Document r265876, power management bug with Intel Turbo Boost.
  
  Sponsored by: The FreeBSD Foundation

Modified:
  head/release/doc/en_US.ISO8859-1/relnotes/article.xml

Modified: head/release/doc/en_US.ISO8859-1/relnotes/article.xml
==
--- head/release/doc/en_US.ISO8859-1/relnotes/article.xml   Wed May 14 
15:30:49 2014(r266031)
+++ head/release/doc/en_US.ISO8859-1/relnotes/article.xml   Wed May 14 
15:31:16 2014(r266032)
@@ -155,6 +155,11 @@
&man.mrsas.4;.
 
 
+A kernel bug that inhibited proper
+  functionality of the dev.cpu.0.freq
+  &man.sysctl.8; on &intel; processors with Turbo
+  Boost ™ enabled has been fixed.
+
 
   Virtualization support
 
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r266051 - head/sys/dev/usb/controller

2014-05-14 Thread Hans Petter Selasky
Author: hselasky
Date: Wed May 14 17:04:02 2014
New Revision: 266051
URL: http://svnweb.freebsd.org/changeset/base/266051

Log:
  Implement USB device side driver code for SAF1761 and compatible
  chips, based on datasheet and existing USS820 DCI driver. This code is
  not yet tested.
  
  Sponsored by: DARPA, AFRL

Modified:
  head/sys/dev/usb/controller/saf1761_dci.c
  head/sys/dev/usb/controller/saf1761_dci.h
  head/sys/dev/usb/controller/saf1761_dci_fdt.c
  head/sys/dev/usb/controller/saf1761_dci_reg.h

Modified: head/sys/dev/usb/controller/saf1761_dci.c
==
--- head/sys/dev/usb/controller/saf1761_dci.c   Wed May 14 17:01:35 2014
(r266050)
+++ head/sys/dev/usb/controller/saf1761_dci.c   Wed May 14 17:04:02 2014
(r266051)
@@ -1,6 +1,6 @@
 /* $FreeBSD$ */
 /*-
- * Copyright (c) 2014 Hans Petter Selasky
+ * Copyright (c) 2014 Hans Petter Selasky 
  * All rights reserved.
  *
  * This software was developed by SRI International and the University of
@@ -29,5 +29,1958 @@
  * SUCH DAMAGE.
  */
 
+/*
+ * This file contains the driver for the SAF1761 series USB OTG
+ * controller.
+ *
+ * Datasheet is available from:
+ * http://www.nxp.com/products/automotive/multimedia/usb/SAF1761BE.html
+ */
+
+#ifdef USB_GLOBAL_INCLUDE_FILE
+#include USB_GLOBAL_INCLUDE_FILE
+#else
+#include 
+#include 
+#include 
+#include 
+#include 
+#include 
+#include 
+#include 
+#include 
+#include 
+#include 
+#include 
+#include 
+#include 
+#include 
+#include 
+#include 
+#include 
+
+#include 
+#include 
+
+#defineUSB_DEBUG_VAR saf1761_dci_debug
+
+#include 
+#include 
+#include 
+#include 
+#include 
+#include 
+#include 
+#include 
+
+#include 
+#include 
+#endif /* USB_GLOBAL_INCLUDE_FILE */
+
 #include 
 #include 
+
+#defineSAF1761_DCI_BUS2SC(bus) \
+   ((struct saf1761_dci_softc *)(((uint8_t *)(bus)) - \
+((uint8_t *)&(((struct saf1761_dci_softc *)0)->sc_bus
+
+#ifdef USB_DEBUG
+static int saf1761_dci_debug = 0;
+static int saf1761_dci_forcefs = 0;
+
+static 
+SYSCTL_NODE(_hw_usb, OID_AUTO, saf1761_dci, CTLFLAG_RW, 0,
+"USB SAF1761 DCI");
+
+SYSCTL_INT(_hw_usb_saf1761_dci, OID_AUTO, debug, CTLFLAG_RW,
+&saf1761_dci_debug, 0, "SAF1761 DCI debug level");
+SYSCTL_INT(_hw_usb_saf1761_dci, OID_AUTO, forcefs, CTLFLAG_RW,
+&saf1761_dci_forcefs, 0, "SAF1761 DCI force FULL speed");
+#endif
+
+#defineSAF1761_DCI_INTR_ENDPT 1
+
+/* prototypes */
+
+static const struct usb_bus_methods saf1761_dci_bus_methods;
+static const struct usb_pipe_methods saf1761_dci_device_non_isoc_methods;
+static const struct usb_pipe_methods saf1761_dci_device_isoc_methods;
+
+static saf1761_dci_cmd_t saf1761_dci_setup_rx;
+static saf1761_dci_cmd_t saf1761_dci_data_rx;
+static saf1761_dci_cmd_t saf1761_dci_data_tx;
+static saf1761_dci_cmd_t saf1761_dci_data_tx_sync;
+static void saf1761_dci_device_done(struct usb_xfer *, usb_error_t);
+static void saf1761_dci_do_poll(struct usb_bus *);
+static void saf1761_dci_standard_done(struct usb_xfer *);
+static void saf1761_dci_intr_set(struct usb_xfer *, uint8_t);
+static void saf1761_dci_root_intr(struct saf1761_dci_softc *);
+
+/*
+ * Here is a list of what the SAF1761 chip can support. The main
+ * limitation is that the sum of the buffer sizes must be less than
+ * 8192 bytes.
+ */
+static const struct usb_hw_ep_profile saf1761_dci_ep_profile[] = {
+
+   [0] = {
+   .max_in_frame_size = 64,
+   .max_out_frame_size = 64,
+   .is_simplex = 0,
+   .support_control = 1,
+   },
+   [1] = {
+   .max_in_frame_size = SOTG_HS_MAX_PACKET_SIZE,
+   .max_out_frame_size = SOTG_HS_MAX_PACKET_SIZE,
+   .is_simplex = 0,
+   .support_interrupt = 1,
+   .support_bulk = 1,
+   .support_isochronous = 1,
+   .support_in = 1,
+   .support_out = 1,
+   },
+};
+
+static void
+saf1761_dci_get_hw_ep_profile(struct usb_device *udev,
+const struct usb_hw_ep_profile **ppf, uint8_t ep_addr)
+{
+   if (ep_addr == 0) {
+   *ppf = saf1761_dci_ep_profile + 0;
+   } else if (ep_addr < 8) {
+   *ppf = saf1761_dci_ep_profile + 1;
+   } else {
+   *ppf = NULL;
+   }
+}
+
+static void
+saf1761_dci_pull_up(struct saf1761_dci_softc *sc)
+{
+   /* activate pullup on D+, if possible */
+
+   if (!sc->sc_flags.d_pulled_up && sc->sc_flags.port_powered) {
+   DPRINTF("\n");
+
+   sc->sc_flags.d_pulled_up = 1;
+
+   SAF1761_WRITE_2(sc, SOTG_CTRL_SET, SOTG_CTRL_DP_PULL_UP);
+   }
+}
+
+static void
+saf1761_dci_pull_down(struct saf1761_dci_softc *sc)
+{
+   /* release pullup on D+, if possible */
+
+   if (sc->sc_flags.d_pulled_up) {
+   DPRINTF("\n");
+
+   sc->sc_flags.d_pulled_up = 0;
+
+   S

Re: svn commit: r265358 - head/sys/dev/usb/controller

2014-05-14 Thread Adrian Chadd
On 14 May 2014 04:37, Hans Petter Selasky  wrote:
> Hi,
>
> See:
>
> http://svnweb.freebsd.org/changeset/base/266012
>
> Sorry, I cannot test all platforms currently because some configuration is
> specific to each hardware platform.

So where do we send you hardware, and what do you need? :-)


-a
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r266053 - head/lib/clang

2014-05-14 Thread Dimitry Andric
Author: dim
Date: Wed May 14 17:11:57 2014
New Revision: 266053
URL: http://svnweb.freebsd.org/changeset/base/266053

Log:
  Use the new -d option that was added to tblgen between llvm/clang 3.3
  and 3.4 to generate dependency files for the '.inc.h' files generated
  from .td files, and .sinclude those dependency files in clang.build.mk.
  
  This will make future incremental builds of lib/clang and usr.bin/clang
  work correctly, whenever any of the .td files get modified.
  
  Note that this will not fix any problems with incremental builds from
  *before* this revision, since there will not yet be any generated
  dependency files.  A quick workaround is to run the following:
  
find /usr/obj -type f -name '*.inc.h' | xargs rm
  
  and then a regular incremental buildworld (e.g. with -DNO_CLEAN).
  
  MFC after:3 days

Modified:
  head/lib/clang/clang.build.mk

Modified: head/lib/clang/clang.build.mk
==
--- head/lib/clang/clang.build.mk   Wed May 14 17:07:14 2014
(r266052)
+++ head/lib/clang/clang.build.mk   Wed May 14 17:11:57 2014
(r266053)
@@ -43,17 +43,9 @@ CXXFLAGS+=   -fno-exceptions -fno-rtti
 TBLGEN?=   tblgen
 CLANG_TBLGEN?= clang-tblgen
 
-Intrinsics.inc.h: ${LLVM_SRCS}/include/llvm/IR/Intrinsics.td \
- ${LLVM_SRCS}/include/llvm/IR/IntrinsicsARM.td \
- ${LLVM_SRCS}/include/llvm/IR/IntrinsicsHexagon.td \
- ${LLVM_SRCS}/include/llvm/IR/IntrinsicsMips.td \
- ${LLVM_SRCS}/include/llvm/IR/IntrinsicsNVVM.td \
- ${LLVM_SRCS}/include/llvm/IR/IntrinsicsPowerPC.td \
- ${LLVM_SRCS}/include/llvm/IR/IntrinsicsR600.td \
- ${LLVM_SRCS}/include/llvm/IR/IntrinsicsX86.td \
- ${LLVM_SRCS}/include/llvm/IR/IntrinsicsXCore.td
-   ${TBLGEN} -I ${LLVM_SRCS}/include \
-   -gen-intrinsic -o ${.TARGET} \
+Intrinsics.inc.h: ${LLVM_SRCS}/include/llvm/IR/Intrinsics.td
+   ${TBLGEN} -gen-intrinsic \
+   -I ${LLVM_SRCS}/include -d ${.TARGET:C/\.h$/.d/} -o ${.TARGET} \
${LLVM_SRCS}/include/llvm/IR/Intrinsics.td
 .for arch in \
ARM/ARM Mips/Mips PowerPC/PPC Sparc/Sparc X86/X86
@@ -72,144 +64,167 @@ Intrinsics.inc.h: ${LLVM_SRCS}/include/l
RegisterInfo/-gen-register-info \
SubtargetInfo/-gen-subtarget
 ${arch:T}Gen${hdr:H:C/$/.inc.h/}: 
${LLVM_SRCS}/lib/Target/${arch:H}/${arch:T}.td
-   ${TBLGEN} -I ${LLVM_SRCS}/include -I ${LLVM_SRCS}/lib/Target/${arch:H} \
-   ${hdr:T:C/,/ /g} -o ${.TARGET} \
+   ${TBLGEN} ${hdr:T:C/,/ /g} \
+   -I ${LLVM_SRCS}/include -I ${LLVM_SRCS}/lib/Target/${arch:H} \
+   -d ${.TARGET:C/\.h$/.d/} -o ${.TARGET} \
${LLVM_SRCS}/lib/Target/${arch:H}/${arch:T}.td
 . endfor
 .endfor
 
 Attrs.inc.h: ${CLANG_SRCS}/include/clang/Basic/Attr.td
-   ${CLANG_TBLGEN} -I ${CLANG_SRCS}/include \
-   -gen-clang-attr-classes -o ${.TARGET} ${.ALLSRC}
+   ${CLANG_TBLGEN} -gen-clang-attr-classes \
+   -I ${CLANG_SRCS}/include -d ${.TARGET:C/\.h$/.d/} -o ${.TARGET} \
+   ${.ALLSRC}
 
 AttrDump.inc.h: ${CLANG_SRCS}/include/clang/Basic/Attr.td
-   ${CLANG_TBLGEN} -I ${CLANG_SRCS}/include \
-   -gen-clang-attr-dump -o ${.TARGET} ${.ALLSRC}
+   ${CLANG_TBLGEN} -gen-clang-attr-dump \
+   -I ${CLANG_SRCS}/include -d ${.TARGET:C/\.h$/.d/} -o ${.TARGET} \
+   ${.ALLSRC}
 
 AttrIdentifierArg.inc.h: ${CLANG_SRCS}/include/clang/Basic/Attr.td
-   ${CLANG_TBLGEN} -I ${CLANG_SRCS}/include \
-   -gen-clang-attr-identifier-arg-list -o ${.TARGET} ${.ALLSRC}
+   ${CLANG_TBLGEN} -gen-clang-attr-identifier-arg-list \
+   -I ${CLANG_SRCS}/include -d ${.TARGET:C/\.h$/.d/} -o ${.TARGET} \
+   ${.ALLSRC}
 
 AttrImpl.inc.h: ${CLANG_SRCS}/include/clang/Basic/Attr.td
-   ${CLANG_TBLGEN} -I ${CLANG_SRCS}/include \
-   -gen-clang-attr-impl -o ${.TARGET} ${.ALLSRC}
+   ${CLANG_TBLGEN} -gen-clang-attr-impl \
+   -I ${CLANG_SRCS}/include -d ${.TARGET:C/\.h$/.d/} -o ${.TARGET} \
+   ${.ALLSRC}
 
 AttrLateParsed.inc.h: ${CLANG_SRCS}/include/clang/Basic/Attr.td
-   ${CLANG_TBLGEN} -I ${CLANG_SRCS}/include \
-   -gen-clang-attr-late-parsed-list -o ${.TARGET} ${.ALLSRC}
+   ${CLANG_TBLGEN} -gen-clang-attr-late-parsed-list \
+   -I ${CLANG_SRCS}/include -d ${.TARGET:C/\.h$/.d/} -o ${.TARGET} \
+   ${.ALLSRC}
 
 AttrList.inc.h: ${CLANG_SRCS}/include/clang/Basic/Attr.td
-   ${CLANG_TBLGEN} -I ${CLANG_SRCS}/include \
-   -gen-clang-attr-list -o ${.TARGET} ${.ALLSRC}
+   ${CLANG_TBLGEN} -gen-clang-attr-list \
+   -I ${CLANG_SRCS}/include -d ${.TARGET:C/\.h$/.d/} -o ${.TARGET} \
+   ${.ALLSRC}
 
 AttrParsedAttrImpl.inc.h: ${CLANG_SRCS}/include/clang/Basic/Attr.td
-   ${CLANG_TBLGEN} -I ${CLANG_SRCS}/include \
-   -gen-clang-attr-

svn commit: r266074 - in head: etc/mtree usr.bin/bmake usr.bin/bmake/tests usr.bin/bmake/tests/archives usr.bin/bmake/tests/archives/fmt_44bsd usr.bin/bmake/tests/archives/fmt_44bsd_mod usr.bin/bma...

2014-05-14 Thread Julio Merino
Author: jmmv
Date: Wed May 14 18:43:13 2014
New Revision: 266074
URL: http://svnweb.freebsd.org/changeset/base/266074

Log:
  Move old fmake tests into bmake and hook them to the build.
  
  This first step is mostly to prevent the code from rotting even further
  and to ensure these do not get wiped when fmake's code is removed from
  the tree.
  
  These tests are currently being skipped because they detect the underlying
  make is not fmake and thus disable themselves -- and the reason is that
  some of the tests fail, possibly due to legitimate bugs.  Enabling them to
  run against bmake will come separately.
  
  Lastly, it would be ideal if these tests were fed upstream but they are
  not ready for that yet.  In the interim, just put them under usr.bin/bmake/
  while we sort things out.  The existence of a different unit-tests directory
  within here makes me feel less guilty about this.
  
  Change confirmed working with a clean amd64 build.

Added:
  head/usr.bin/bmake/tests/
 - copied from r266046, head/usr.bin/make/tests/
Deleted:
  head/usr.bin/make/tests/
Modified:
  head/etc/mtree/BSD.tests.dist
  head/usr.bin/bmake/Makefile
  head/usr.bin/bmake/tests/Makefile
  head/usr.bin/bmake/tests/archives/Makefile
  head/usr.bin/bmake/tests/archives/fmt_44bsd/Makefile
  head/usr.bin/bmake/tests/archives/fmt_44bsd_mod/Makefile
  head/usr.bin/bmake/tests/archives/fmt_oldbsd/Makefile
  head/usr.bin/bmake/tests/basic/Makefile
  head/usr.bin/bmake/tests/basic/t0/Makefile
  head/usr.bin/bmake/tests/basic/t1/Makefile
  head/usr.bin/bmake/tests/basic/t2/Makefile
  head/usr.bin/bmake/tests/basic/t3/Makefile
  head/usr.bin/bmake/tests/execution/Makefile
  head/usr.bin/bmake/tests/execution/ellipsis/Makefile
  head/usr.bin/bmake/tests/execution/empty/Makefile
  head/usr.bin/bmake/tests/execution/joberr/Makefile
  head/usr.bin/bmake/tests/execution/plus/Makefile
  head/usr.bin/bmake/tests/shell/Makefile
  head/usr.bin/bmake/tests/shell/builtin/Makefile
  head/usr.bin/bmake/tests/shell/meta/Makefile
  head/usr.bin/bmake/tests/shell/path/Makefile
  head/usr.bin/bmake/tests/shell/path_select/Makefile
  head/usr.bin/bmake/tests/shell/replace/Makefile
  head/usr.bin/bmake/tests/shell/select/Makefile
  head/usr.bin/bmake/tests/suffixes/Makefile
  head/usr.bin/bmake/tests/suffixes/basic/Makefile
  head/usr.bin/bmake/tests/suffixes/src_wild1/Makefile
  head/usr.bin/bmake/tests/suffixes/src_wild2/Makefile
  head/usr.bin/bmake/tests/syntax/Makefile
  head/usr.bin/bmake/tests/syntax/directive-t0/Makefile
  head/usr.bin/bmake/tests/syntax/enl/Makefile
  head/usr.bin/bmake/tests/syntax/funny-targets/Makefile
  head/usr.bin/bmake/tests/syntax/semi/Makefile
  head/usr.bin/bmake/tests/sysmk/Makefile
  head/usr.bin/bmake/tests/sysmk/t0/2/1/Makefile
  head/usr.bin/bmake/tests/sysmk/t0/2/Makefile
  head/usr.bin/bmake/tests/sysmk/t0/Makefile
  head/usr.bin/bmake/tests/sysmk/t0/mk/Makefile
  head/usr.bin/bmake/tests/sysmk/t1/2/1/Makefile
  head/usr.bin/bmake/tests/sysmk/t1/2/Makefile
  head/usr.bin/bmake/tests/sysmk/t1/Makefile
  head/usr.bin/bmake/tests/sysmk/t1/mk/Makefile
  head/usr.bin/bmake/tests/sysmk/t2/2/1/Makefile
  head/usr.bin/bmake/tests/sysmk/t2/2/Makefile
  head/usr.bin/bmake/tests/sysmk/t2/Makefile
  head/usr.bin/bmake/tests/sysmk/t2/mk/Makefile
  head/usr.bin/bmake/tests/variables/Makefile
  head/usr.bin/bmake/tests/variables/modifier_M/Makefile
  head/usr.bin/bmake/tests/variables/modifier_t/Makefile
  head/usr.bin/bmake/tests/variables/opt_V/Makefile
  head/usr.bin/bmake/tests/variables/t0/Makefile
  head/usr.bin/make/Makefile

Modified: head/etc/mtree/BSD.tests.dist
==
--- head/etc/mtree/BSD.tests.dist   Wed May 14 18:41:59 2014
(r266073)
+++ head/etc/mtree/BSD.tests.dist   Wed May 14 18:43:13 2014
(r266074)
@@ -133,21 +133,7 @@
 atf-sh
 ..
 ..
-calendar
-..
-comm
-..
-file2c
-..
-join
-..
-jot
-..
-lastcomm
-..
-m4
-..
-make
+bmake
 archives
 fmt_44bsd
 ..
@@ -245,6 +231,20 @@
 ..
 ..
 ..
+calendar
+..
+comm
+..
+file2c
+..
+join
+..
+jot
+..
+lastcomm
+..
+m4
+..
 ncal
 ..
 printf

Modified: head/usr.bin/bmake/Makefile
==
--- head/usr.bin/bmake/Makefile Wed May 14 18:41:59 2014(r266073)
+++ head/usr.bin/bmake/Makefile Wed May 14 18:43:13 2014(r266074)
@@ -3,6 +3,7 @@
 #
 # $FreeBSD$
 
+.in

svn commit: r266082 - head/cddl/lib/libdtrace

2014-05-14 Thread Mark Johnston
Author: markj
Date: Wed May 14 19:02:00 2014
New Revision: 266082
URL: http://svnweb.freebsd.org/changeset/base/266082

Log:
  Bind ip/tcp/udp provider translators and symbols to the same versions as in
  illumos, rather than using "1.0" everywhere.
  
  Some of the translators use D functions that are not present in version
  1.0 (e.g. inet_ntoa()) which can result in libdtrace crashing when running
  scripts that restrict themselves to version 1.0
  (e.g. with "-x version=1.0").
  
  MFC after:1 week

Modified:
  head/cddl/lib/libdtrace/ip.d
  head/cddl/lib/libdtrace/tcp.d
  head/cddl/lib/libdtrace/udp.d

Modified: head/cddl/lib/libdtrace/ip.d
==
--- head/cddl/lib/libdtrace/ip.dWed May 14 19:00:01 2014
(r266081)
+++ head/cddl/lib/libdtrace/ip.dWed May 14 19:02:00 2014
(r266082)
@@ -125,53 +125,53 @@ typedef struct ipv6info {
ip6_t *ipv6_hdr;/* pointer to raw header */
 } ipv6info_t;
 
-#pragma D binding "1.0" IPPROTO_IP
+#pragma D binding "1.5" IPPROTO_IP
 inline short IPPROTO_IP =  0;
-#pragma D binding "1.0" IPPROTO_ICMP
+#pragma D binding "1.5" IPPROTO_ICMP
 inline short IPPROTO_ICMP =1;
-#pragma D binding "1.0" IPPROTO_IGMP
+#pragma D binding "1.5" IPPROTO_IGMP
 inline short IPPROTO_IGMP =2;
-#pragma D binding "1.0" IPPROTO_IPV4
+#pragma D binding "1.5" IPPROTO_IPV4
 inline short IPPROTO_IPV4 =4;
-#pragma D binding "1.0" IPPROTO_TCP
+#pragma D binding "1.5" IPPROTO_TCP
 inline short IPPROTO_TCP = 6;
-#pragma D binding "1.0" IPPROTO_UDP
+#pragma D binding "1.5" IPPROTO_UDP
 inline short IPPROTO_UDP = 17;
-#pragma D binding "1.0" IPPROTO_IPV6
+#pragma D binding "1.5" IPPROTO_IPV6
 inline short IPPROTO_IPV6 =41;
-#pragma D binding "1.0" IPPROTO_ROUTING
+#pragma D binding "1.5" IPPROTO_ROUTING
 inline short IPPROTO_ROUTING = 43;
-#pragma D binding "1.0" IPPROTO_FRAGMENT
+#pragma D binding "1.5" IPPROTO_FRAGMENT
 inline short IPPROTO_FRAGMENT =44;
-#pragma D binding "1.0" IPPROTO_RSVP
+#pragma D binding "1.5" IPPROTO_RSVP
 inline short IPPROTO_RSVP =46;
-#pragma D binding "1.0" IPPROTO_GRE
+#pragma D binding "1.5" IPPROTO_GRE
 inline short IPPROTO_GRE = 47;
-#pragma D binding "1.0" IPPROTO_ESP
+#pragma D binding "1.5" IPPROTO_ESP
 inline short IPPROTO_ESP = 50;
-#pragma D binding "1.0" IPPROTO_AH
+#pragma D binding "1.5" IPPROTO_AH
 inline short IPPROTO_AH =  51;
-#pragma D binding "1.0" IPPROTO_MOBILE
+#pragma D binding "1.5" IPPROTO_MOBILE
 inline short IPPROTO_MOBILE =  55;
-#pragma D binding "1.0" IPPROTO_ICMPV6
+#pragma D binding "1.5" IPPROTO_ICMPV6
 inline short IPPROTO_ICMPV6 =  58;
-#pragma D binding "1.0" IPPROTO_DSTOPTS
+#pragma D binding "1.5" IPPROTO_DSTOPTS
 inline short IPPROTO_DSTOPTS = 60;
-#pragma D binding "1.0" IPPROTO_ETHERIP
+#pragma D binding "1.5" IPPROTO_ETHERIP
 inline short IPPROTO_ETHERIP = 97;
-#pragma D binding "1.0" IPPROTO_PIM
+#pragma D binding "1.5" IPPROTO_PIM
 inline short IPPROTO_PIM = 103;
-#pragma D binding "1.0" IPPROTO_IPCOMP
+#pragma D binding "1.5" IPPROTO_IPCOMP
 inline short IPPROTO_IPCOMP =  108;
-#pragma D binding "1.0" IPPROTO_SCTP
+#pragma D binding "1.5" IPPROTO_SCTP
 inline short IPPROTO_SCTP =132;
-#pragma D binding "1.0" IPPROTO_RAW
+#pragma D binding "1.5" IPPROTO_RAW
 inline short IPPROTO_RAW = 255;
 
 inline uint8_t INP_IPV4= 0x01;
 inline uint8_t INP_IPV6 = 0x02;
 
-#pragma D binding "1.0" protocols
+#pragma D binding "1.5" protocols
 inline string protocols[int proto] =
proto == IPPROTO_IP ? "IP" :
proto == IPPROTO_ICMP ? "ICMP" :
@@ -200,12 +200,12 @@ inline string protocols[int proto] =
  * This field is always NULL according to the current definition of the ip
  * probes.
  */
-#pragma D binding "1.0" translator
+#pragma D binding "1.5" translator
 translator pktinfo_t < void *p > {
pkt_addr =  NULL;
 };
 
-#pragma D binding "1.0" translator
+#pragma D binding "1.5" translator
 translator csinfo_t < void *p > {
cs_addr =   NULL;
cs_cid =(uint64_t)p;
@@ -213,7 +213,7 @@ translator csinfo_t < void *p > {
cs_zoneid = 0;
 };
 
-#pragma D binding "1.0" translator
+#pragma D binding "1.6.3" translator
 translator csinfo_t < struct inpcb *p > {
cs_addr =   NULL;
cs_cid =(uint64_t)p;
@@ -221,7 +221,7 @@ translator csinfo_t < struct inpcb *p > 
cs_zoneid = 0;
 };
 
-#pragma D binding "1.0" translator
+#pragma D binding "1.5" translator
 translator ipinfo_t < uint8_t *p > {
ip_ver =p == NULL ? 0 : ((struct ip *)p)->ip_v;
ip_plength =p == NULL ? 0 :
@@ -238,17 +238,17 @@ translator ipinfo_t < uint8_t *p > {
inet_ntoa6(&((struct ip6_hdr *)p)->ip6_dst);
 };
 
-#pragma D binding "1.0" IFF_LOOPBACK
+#pragma D binding "1.5" IFF_LOOPBACK
 inline int IFF_LOOPBACK =  0x8;
 
-#pragma D binding "1.0" translator
+

svn commit: r266083 - in head/sys/arm: arm include

2014-05-14 Thread Mark Murray
Author: markm
Date: Wed May 14 19:11:15 2014
New Revision: 266083
URL: http://svnweb.freebsd.org/changeset/base/266083

Log:
  Give suitably-endowed ARMs a register similar to the x86 TSC register.
  
  Here, "suitably endowed" means that the System Control Coprocessor
  (#15) has Performance Monitoring Registers, including a CCNT (Cycle
  Count) register.
  
  The CCNT register is used in a way similar to the TSC register in
  x86 processors by the get_cyclecount(9) function. The entropy-harvesting
  thread is a heavy user of this function, and will benefit from not
  having to call binuptime(9) instead.
  
  One problem with the CCNT register is that it is 32-bit only, so
  the upper 32-bits of the returned number are always 0. The entropy
  harvester does not care, but in case any one else does, follow-up
  work may include an interrup trap to increment an upper-32-bit
  counter on CCNT overflow.
  
  Another problem is that the CCNT register is not readable in user-mode
  code; in can be made readable by userland, but then it is also
  writable, and so is a good chunk of the PMU system. For that reason,
  the CCNT is not enabled for user-mode access in this commit.
  
  Like the x86, there is one CCNT per core, so they don't all run in
  perfect sync.
  
  Reviewed by:  ian@ (an earlier version)
  Tested by:ian@ (same earlier version)
  Committed from:   WANDBOARD-QUAD

Modified:
  head/sys/arm/arm/cpufunc.c
  head/sys/arm/include/cpu.h

Modified: head/sys/arm/arm/cpufunc.c
==
--- head/sys/arm/arm/cpufunc.c  Wed May 14 19:02:00 2014(r266082)
+++ head/sys/arm/arm/cpufunc.c  Wed May 14 19:11:15 2014(r266083)
@@ -1398,6 +1398,37 @@ arm10_setup(args)
 }
 #endif /* CPU_ARM9E || CPU_ARM10 */
 
+#if defined(CPU_ARM1136) || defined(CPU_ARM1176) \
+ || defined(CPU_MV_PJ4B) \
+ || defined(CPU_CORTEXA) || defined(CPU_KRAIT)
+static __inline void
+cpu_scc_setup_ccnt(void)
+{
+/* This is how you give userland access to the CCNT and PMCn
+ * registers.
+ * BEWARE! This gives write access also, which may not be what
+ * you want!
+ */
+#ifdef _PMC_USER_READ_WRITE_
+   /* Set PMUSERENR[0] to allow userland access */
+   __asm volatile ("mcrp15, 0, %0, c9, c14, 0\n\t"
+   :
+   : "r"(0x0001));
+#endif
+/* Set up the PMCCNTR register as a cyclecounter:
+* Set PMINTENCLR to 0x to block interrupts
+* Set PMCR[2,0] to enable counters and reset CCNT
+* Set PMCNTENSET to 0x8000 to enable CCNT */
+   __asm volatile ("mcrp15, 0, %0, c9, c14, 2\n\t"
+   "mcrp15, 0, %1, c9, c12, 0\n\t"
+   "mcrp15, 0, %2, c9, c12, 1\n\t"
+   :
+   : "r"(0x),
+ "r"(0x0005),
+ "r"(0x8000));
+}
+#endif
+
 #if defined(CPU_ARM1136) || defined(CPU_ARM1176)
 struct cpu_option arm11_options[] = {
{ "cpu.cache",  BIC, OR,  (CPU_CONTROL_IC_ENABLE | 
CPU_CONTROL_DC_ENABLE) },
@@ -1501,6 +1532,8 @@ arm11x6_setup(char *args)
 
/* And again. */
cpu_idcache_wbinv_all();
+
+   cpu_scc_setup_ccnt();
 }
 #endif  /* CPU_ARM1136 || CPU_ARM1176 */
 
@@ -1535,6 +1568,8 @@ pj4bv7_setup(args)
 
/* And again. */
cpu_idcache_wbinv_all();
+
+   cpu_scc_setup_ccnt();
 }
 #endif /* CPU_MV_PJ4B */
 
@@ -1582,6 +1617,8 @@ cortexa_setup(char *args)
 #ifdef SMP
armv7_auxctrl((1 << 6) | (1 << 0), (1 << 6) | (1 << 0)); /* Enable SMP 
+ TLB broadcasting  */
 #endif
+
+   cpu_scc_setup_ccnt();
 }
 #endif  /* CPU_CORTEXA */
 

Modified: head/sys/arm/include/cpu.h
==
--- head/usr.bin/bmake/Makefile Thu May 15 01:06:27 2014(r266103)
+++ head/usr.bin/bmake/Makefile Thu May 15 01:27:24 2014(r266104)
@@ -3,7 +3,6 @@
 #
 # $FreeBSD$
 
-.include 
 .sinclude "Makefile.inc"
 
 SRCTOP?= ${.CURDIR:H:H}
@@ -107,11 +106,6 @@ COPTS.meta.c += -DHAVE_FILEMON_H -I${FIL
 SUBDIR+= unit-tests
 .endif
 
-.if ${MK_TESTS} != no
-SUBDIR+= tests
-.endif
-
-
 MAN= ${PROG}.1
 MAN1= ${MAN}
 

Modified: head/usr.bin/bmake/Makefile.inc
==
--- head/usr.bin/bmake/Makefile.inc Thu May 15 01:06:27 2014
(r266103)
+++ head/usr.bin/bmake/Makefile.inc Thu May 15 01:27:24 2014
(r266104)
@@ -13,5 +13,9 @@ PROG= make
 NO_SHARED?= YES
 .endif
 
+.if defined(MK_TESTS) && ${MK_TESTS} != no
+SUBDIR+= tests
+.endif
+
 WARNS=3
 CFLAGS+= -DNO_PWD_OVERRIDE
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r266107 - head/usr.sbin/bsdinstall/scripts

2014-05-14 Thread Ollivier Robert
Author: roberto
Date: Thu May 15 02:27:10 2014
New Revision: 266107
URL: http://svnweb.freebsd.org/changeset/base/266107

Log:
  Here is a patch for the bsdinstall root-on-zfs stuff that adds optional
  encryption for swap, and optional gmirror for swap (which can be combined)
  
  Submitted by: Allan Jude 
  Requested By: roberto
  Sponsored By: ScaleEngine Inc.
  MFC after:2 weeks

Modified:
  head/usr.sbin/bsdinstall/scripts/zfsboot

Modified: head/usr.sbin/bsdinstall/scripts/zfsboot
==
--- head/usr.sbin/bsdinstall/scripts/zfsbootThu May 15 01:37:17 2014
(r266106)
+++ head/usr.sbin/bsdinstall/scripts/zfsbootThu May 15 02:27:10 2014
(r266107)
@@ -108,6 +108,16 @@ f_include $BSDCFG_SHARE/variable.subr
 : ${ZFSBOOT_SWAP_SIZE:=2g}
 
 #
+# Should we use geli(8) to encrypt the swap?
+#
+: ${ZFSBOOT_SWAP_ENCRYPTION=}
+
+#
+# Should we use gmirror(8) to mirror the swap?
+#
+: ${ZFSBOOT_SWAP_MIRROR=}
+
+#
 # Default ZFS datasets for root zpool
 #
 # NOTE: Requires /tmp, /var/tmp, /$ZFSBOOT_BOOTFS_NAME/$ZFSBOOT_BOOTFS_NAME
@@ -184,6 +194,7 @@ MOUNT_TYPE='mount -t %s "%s" "%s"'
 PRINTF_CONF="printf '%s=\"%%s\"\\\n' %s >> \"%s\""
 PRINTF_FSTAB='printf "$FSTAB_FMT" "%s" "%s" "%s" "%s" "%s" "%s" >> "%s"'
 SHELL_TRUNCATE=':> "%s"'
+SWAP_GMIRROR_LABEL='gmirror label swap %s'
 UMOUNT='umount "%s"'
 ZFS_CREATE_WITH_OPTIONS='zfs create %s "%s"'
 ZFS_SET='zfs set "%s" "%s"'
@@ -263,6 +274,10 @@ msg_select_a_disk_device="Select a disk 
 msg_select_virtual_device_type="Select Virtual Device type:"
 msg_stripe_desc="Stripe - No Redundancy"
 msg_stripe_help="[1+ Disks] Striping provides maximum storage but no 
redundancy"
+msg_swap_encrypt="Encrypt Swap?"
+msg_swap_encrypt_help="Encrypt swap partitions with temporary keys, discarded 
on reboot"
+msg_swap_mirror="Mirror Swap?"
+msg_swap_mirror_help="Mirror swap partitions for redundancy, breaks crash 
dumps"
 msg_swap_size="Swap Size"
 msg_swap_size_help="Customize how much swap space is allocated to each 
selected disk"
 msg_these_disks_are_too_small="These disks are too small given the amount of 
requested\nswap (%s) and/or geli(8) (%s) partitions, which would\ntake 50%% or 
more of each of the following selected disk\ndevices (not recommended):\n\n  
%s\n\nRecommend changing partition size(s) and/or selecting a\ndifferent set of 
devices."
@@ -285,8 +300,12 @@ dialog_menu_main()
local prompt="$msg_configure_options"
local force4k="$msg_no"
local usegeli="$msg_no"
+   local swapgeli="$msg_no"
+   local swapmirror="$msg_no"
[ "$ZFSBOOT_GNOP_4K_FORCE_ALIGN" ] && force4k="$msg_yes"
[ "$ZFSBOOT_GELI_ENCRYPTION" ] && usegeli="$msg_yes"
+   [ "$ZFSBOOT_SWAP_ENCRYPTION" ] && swapgeli="$msg_yes"
+   [ "$ZFSBOOT_SWAP_MIRROR" ] && swapmirror="$msg_yes"
local disks n
f_count n $ZFSBOOT_DISKS
{ [ $n -eq 1 ] && disks=disk; } || disks=disks # grammar
@@ -309,6 +328,10 @@ dialog_menu_main()
  '$msg_partition_scheme_help'
'S $msg_swap_size''$ZFSBOOT_SWAP_SIZE'
  '$msg_swap_size_help'
+   'M $msg_swap_mirror'  '$swapmirror'
+ '$msg_swap_mirror_help'
+   'W $msg_swap_encrypt' '$swapgeli'
+ '$msg_swap_encrypt_help'
" # END-QUOTE
local defaultitem= # Calculated below
local hline="$hline_alnum_arrows_punc_tab_enter"
@@ -747,14 +770,14 @@ zfs_create_diskpart()
 return $FAILURE
 
# NB: zpool will use the `zfs#' GPT labels
-   bootpart=p2 targetpart=p2
+   bootpart=p2 swappart=p2 targetpart=p2
[ ${swapsize:-0} -gt 0 ] && targetpart=p3
 
#
# Prepare boot pool if enabled (e.g., for geli(8))
#
if [ "$ZFSBOOT_BOOT_POOL" ]; then
-   bootpart=p2 targetpart=p3
+   bootpart=p2 swappart=p3 targetpart=p3
[ ${swapsize:-0} -gt 0 ] && targetpart=p4
f_eval_catch $funcname gpart \
 "$GPART_ADD_LABEL_WITH_SIZE" boot$index \
@@ -781,12 +804,7 @@ zfs_create_diskpart()
 return $FAILURE
# Pedantically nuke any old labels on the swap
f_eval_catch -d $funcname zpool "$ZPOOL_LABELCLEAR_F" \
-   /dev/gpt/swap$index
-   # Update fstab(5)
-   f_eval_catch $funcname printf "$PRINTF_FSTAB" \
-/dev/gpt/swap$index none swap sw 0 0 \
-$BSDINSTALL_TMPETC/fstab ||
-return $FAILU

svn commit: r266108 - head/usr.sbin/bsdinstall/scripts

2014-05-14 Thread Ollivier Robert
Author: roberto
Date: Thu May 15 02:31:02 2014
New Revision: 266108
URL: http://svnweb.freebsd.org/changeset/base/266108

Log:
  Updates to the datasets created by zfsboot.
  
  Set compress=lz4 for the entire pool, removing it from the individual
  datasets
  
  Remove exec=no from /usr/src, breaks the test suite.
  
  Submitted by: Allan Jude 
  Reviewed by:  roberto
  MFC after:2 weeks
  Sponsored by: ScaleEngine Inc.

Modified:
  head/usr.sbin/bsdinstall/scripts/zfsboot

Modified: head/usr.sbin/bsdinstall/scripts/zfsboot
==
--- head/usr.sbin/bsdinstall/scripts/zfsbootThu May 15 02:27:10 2014
(r266107)
+++ head/usr.sbin/bsdinstall/scripts/zfsbootThu May 15 02:31:02 2014
(r266108)
@@ -131,7 +131,7 @@ f_isset ZFSBOOT_DATASETS || ZFSBOOT_DATA
/$ZFSBOOT_BEROOT_NAME/$ZFSBOOT_BOOTFS_NAME  mountpoint=/
 
# Compress /tmp, allow exec but not setuid
-   /tmpmountpoint=/tmp,compression=lz4,exec=on,setuid=off
+   /tmpmountpoint=/tmp,exec=on,setuid=off
 
# Don't mount /usr so that 'base' files go to the BEROOT
/usrmountpoint=/usr,canmount=off
@@ -140,17 +140,17 @@ f_isset ZFSBOOT_DATASETS || ZFSBOOT_DATA
/usr/home   # NB: /home is a symlink to /usr/home
 
# Ports tree
-   /usr/ports  compression=lz4,setuid=off
+   /usr/ports  setuid=off
 
# Source tree (compressed)
-   /usr/srccompression=lz4,exec=off,setuid=off
+   /usr/src
 
# Create /var and friends
/varmountpoint=/var
-   /var/crash  compression=lz4,exec=off,setuid=off
-   /var/logcompression=lz4,exec=off,setuid=off
-   /var/mail   compression=lz4,atime=on
-   /var/tmpcompression=lz4,exec=on,setuid=off
+   /var/crash  exec=off,setuid=off
+   /var/logexec=off,setuid=off
+   /var/mail   atime=on
+   /var/tmpsetuid=off
 " # END-QUOTE
 
 #
@@ -1146,7 +1146,8 @@ zfs_create_boot()
#
f_dprintf "$funcname: Creating root pool..."
f_eval_catch $funcname zpool "$ZPOOL_CREATE_WITH_OPTIONS" \
-"-o altroot=$BSDINSTALL_CHROOT -m none -f" \
+"-o altroot=$BSDINSTALL_CHROOT -O compress=lz4
+-m none -f" \
 "$zroot_name" "$zroot_vdevtype" "$zroot_vdevs" ||
 return $FAILURE
 
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r266109 - head/usr.sbin/bsdinstall/scripts

2014-05-14 Thread Ollivier Robert
Author: roberto
Date: Thu May 15 02:37:59 2014
New Revision: 266109
URL: http://svnweb.freebsd.org/changeset/base/266109

Log:
  Fix the "disks" variable reuse.
  
  It starts off being used to track the grammar for the number of disks
  (singular vs plural) and then it is reused as the list of available disks.
  
  Replace the variable with disks_grammar and move 'disk' and 'disks' to
  msg_ vars so they can be translated in the future.
  
  Submitted by: Allan Jude 
  Reviewed by:  roberto
  MFC after:2 weeks
  Sponsored by: ScaleEngine Inc.

Modified:
  head/usr.sbin/bsdinstall/scripts/zfsboot

Modified: head/usr.sbin/bsdinstall/scripts/zfsboot
==
--- head/usr.sbin/bsdinstall/scripts/zfsbootThu May 15 02:31:02 2014
(r266108)
+++ head/usr.sbin/bsdinstall/scripts/zfsbootThu May 15 02:37:59 2014
(r266109)
@@ -220,6 +220,8 @@ msg_configure_options="Configure Options
 msg_detailed_disk_info="gpart(8) show %s:\n%s\n\ncamcontrol(8) inquiry 
%s:\n%s\n\n\ncamcontrol(8) identify %s:\n%s\n"
 msg_disk_info="Disk Info"
 msg_disk_info_help="Get detailed information on disk device(s)"
+msg_disk_singular="disk"
+msg_disk_plural="disks"
 msg_encrypt_disks="Encrypt Disks?"
 msg_encrypt_disks_help="Use geli(8) to encrypt all data partitions"
 msg_error="Error"
@@ -306,13 +308,14 @@ dialog_menu_main()
[ "$ZFSBOOT_GELI_ENCRYPTION" ] && usegeli="$msg_yes"
[ "$ZFSBOOT_SWAP_ENCRYPTION" ] && swapgeli="$msg_yes"
[ "$ZFSBOOT_SWAP_MIRROR" ] && swapmirror="$msg_yes"
-   local disks n
+   local disks n disks_grammar
f_count n $ZFSBOOT_DISKS
-   { [ $n -eq 1 ] && disks=disk; } || disks=disks # grammar
+   { [ $n -eq 1 ] && disks_grammar=$msg_disk_singular; } || 
+   disks_grammar=$msg_disk_plural # grammar
local menu_list="
'>>> $msg_install''$msg_install_desc'
  '$msg_install_help'
-   'T $msg_pool_type_disks'  '$ZFSBOOT_VDEV_TYPE: $n $disks'
+   'T $msg_pool_type_disks'  '$ZFSBOOT_VDEV_TYPE: $n 
$disks_grammar'
   '$msg_pool_type_disks_help'
'- $msg_rescan_devices'   '*'
  '$msg_rescan_devices_help'
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r266111 - head/contrib/tzcode/stdtime

2014-05-14 Thread Gavin Atkinson
Author: gavin
Date: Thu May 15 03:08:20 2014
New Revision: 266111
URL: http://svnweb.freebsd.org/changeset/base/266111

Log:
  Fix typo.  Note that although this file is under contrib, it has diverged
  sufficiently from upstream (including a full whitespace commit and large
  portions rewritten) that this change does not move us further from the
  upstream.
  
  PR:   docs/186608
  Submitted by: Jamie Landeg-Jones 
  MFC after:3 days

Modified:
  head/contrib/tzcode/stdtime/ctime.3

Modified: head/contrib/tzcode/stdtime/ctime.3
==
--- head/contrib/tzcode/stdtime/ctime.3 Thu May 15 02:41:23 2014
(r266110)
+++ head/contrib/tzcode/stdtime/ctime.3 Thu May 15 03:08:20 2014
(r266111)
@@ -342,7 +342,7 @@ Except for
 and the
 .Fn \&_r
 variants of the other functions,
-these functions leaves their result in an internal static object and return
+these functions leave their result in an internal static object and return
 a pointer to that object.
 Subsequent calls to these
 function will modify the same object.
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r266115 - head/sys

2014-05-14 Thread Rui Paulo
Author: rpaulo
Date: Thu May 15 03:47:52 2014
New Revision: 266115
URL: http://svnweb.freebsd.org/changeset/base/266115

Log:
  Add a new target cscope-hook.
  
  This adds a Mercurial hook to automatically update the cscope data base every
  time you pull, switch branch, or update.

Modified:
  head/sys/Makefile

Modified: head/sys/Makefile
==
--- head/sys/Makefile   Thu May 15 03:30:03 2014(r266114)
+++ head/sys/Makefile   Thu May 15 03:47:52 2014(r266115)
@@ -47,6 +47,25 @@ ${.CURDIR}/cscope.files: .PHONY
 cscope-clean:
rm -f cscope.files cscope.out cscope.in.out cscope.po.out
 
+#
+# Installs SCM hooks to update the cscope database every time the source tree
+# is updated.
+# cscope understands incremental updates, so it's considerably faster when only
+# a few files have changed.
+#
+HG_DIR=${.CURDIR}/../.hg
+HG_HOOK=if [ \$$HG_ERROR -eq 0 ]; then cd sys && make -m ../share/mk cscope; fi
+cscope-hook:
+   @if [ -d ${HG_DIR} ]; then  \
+   if [ "`grep hooks ${HG_DIR}/hgrc`" = "" ]; then \
+   echo "[hooks]" >> ${HG_DIR}/hgrc;   \
+   echo "update = ${HG_HOOK}" >> ${HG_DIR}/hgrc;   \
+   echo "Hook installed in ${HG_DIR}/hgrc";\
+   else\
+   echo "Mercurial update hook already exists.";   \
+   fi; \
+   fi
+
 # You need the devel/global and one of editor/emacs* ports for that.
 TAGS ${.CURDIR}/TAGS: ${.CURDIR}/cscope.files
rm -f ${.CURDIR}/TAGS
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r266116 - head/sys/powerpc/aim

2014-05-14 Thread Justin Hibbits
Author: jhibbits
Date: Thu May 15 04:18:06 2014
New Revision: 266116
URL: http://svnweb.freebsd.org/changeset/base/266116

Log:
  A page mask size is 12-bits, not 11.
  
  MFC after:1 week

Modified:
  head/sys/powerpc/aim/trap_subr32.S

Modified: head/sys/powerpc/aim/trap_subr32.S
==
--- head/sys/powerpc/aim/trap_subr32.S  Thu May 15 03:47:52 2014
(r266115)
+++ head/sys/powerpc/aim/trap_subr32.S  Thu May 15 04:18:06 2014
(r266116)
@@ -677,7 +677,7 @@ disitrap:
mtcr%r31
bt  17,realtrap /* branch is user mode */
mfsprg1 %r31/* get old SP */
-   clrrwi  %r31,%r31,11/* Round SP down to nearest page */
+   clrrwi  %r31,%r31,12/* Round SP down to nearest page */
sub.%r30,%r31,%r30  /* SP - DAR */
bge 1f
neg %r30,%r30   /* modulo value */
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r266117 - head/usr.bin/units

2014-05-14 Thread Eitan Adler
Author: eadler
Date: Thu May 15 05:35:00 2014
New Revision: 266117
URL: http://svnweb.freebsd.org/changeset/base/266117

Log:
  units(1): Fix minor typos
  
  Obtained From:DragonflyBSD

Modified:
  head/usr.bin/units/units.c

Modified: head/usr.bin/units/units.c
==
--- head/usr.bin/units/units.c  Thu May 15 04:18:06 2014(r266116)
+++ head/usr.bin/units/units.c  Thu May 15 05:35:00 2014(r266117)
@@ -291,7 +291,7 @@ showunit(struct unittype * theunit)
counter = 1;
}
}
-   if ( counter > 1)
+   if (counter > 1)
printf("%s%d", powerstring, counter);
printf("\n");
 }
@@ -760,7 +760,7 @@ main(int argc, char **argv)
el_source(el, NULL);
history(inhistory, &ev, H_SETSIZE, 800);
if (inhistory == 0)
-   err(1, "Could not initalize history");
+   err(1, "Could not initialize history");
 
if (cap_enter() < 0 && errno != ENOSYS)
err(1, "unable to enter capability mode");
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"
--- head/sys/arm/include/cpu.h  Wed May 14 19:02:00 2014(r266082)
+++ head/sys/arm/include/cpu.h  Wed May 14 19:11:15 2014(r266083)
@@ -14,11 +14,26 @@ voidswi_vm(void *);
 static __inline uint64_t
 get_cyclecount(void)
 {
+/* This '#if' asks the question 'Does CP15/SCC include performance counters?' 
*/
+#if defined(CPU_ARM1136) || defined(CPU_ARM1176) \
+ || defined(CPU_MV_PJ4B) \
+ || defined(CPU_CORTEXA) || defined(CPU_KRAIT)
+   uint32_t ccnt;
+   uint64_t ccnt64;
+
+   /*
+* Read PMCCNTR. Curses! Its only 32 bits.
+* TODO: Fix this by catching overflow with interrupt?
+*/
+   __asm __volatile("mrc p15, 0, %0, c9, c13, 0": "=r" (ccnt));
+   ccnt64 = (uint64_t)ccnt;
+   return (ccnt64);
+#else /* No performance counters, so use binuptime(9). This is slow */
struct bintime bt;
 
binuptime(&bt);
return ((uint64_t)bt.sec << 56 | bt.frac >> 8);
-   
+#endif
 }
 #endif
 
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head

Re: svn commit: r265408 - in head: sys/netinet usr.bin/netstat

2014-05-14 Thread Don Lewis
On  6 May, Gleb Smirnoff wrote:
> Author: glebius
> Date: Tue May  6 00:00:07 2014
> New Revision: 265408
> URL: http://svnweb.freebsd.org/changeset/base/265408
> 
> Log:
>   - Remove net.inet.tcp.reass.overflows sysctl. It counts exactly
> same events that tcpstat's tcps_rcvmemdrop counter counts.
>   - Rename tcps_rcvmemdrop to tcps_rcvreassfull and improve its
> description in netstat(1) output.
>   
>   Sponsored by:   Netflix
>   Sponsored by:   Nginx, Inc.
> 
> Modified:
>   head/sys/netinet/tcp_reass.c
>   head/sys/netinet/tcp_var.h
>   head/usr.bin/netstat/inet.c
> 

 
> Modified: head/sys/netinet/tcp_var.h
> ==
> --- head/sys/netinet/tcp_var.hMon May  5 23:54:13 2014
> (r265407)
> +++ head/sys/netinet/tcp_var.hTue May  6 00:00:07 2014
> (r265408)
> @@ -426,7 +426,7 @@ structtcpstat {
>   uint64_t tcps_rcvbyte;  /* bytes received in sequence */
>   uint64_t tcps_rcvbadsum;/* packets received with ccksum errs */
>   uint64_t tcps_rcvbadoff;/* packets received with bad offset */
> - uint64_t tcps_rcvmemdrop;   /* packets dropped for lack of memory */
> + uint64_t tcps_rcvreassfull; /* packets dropped for no reass space */
>   uint64_t tcps_rcvshort; /* packets received too short */
>   uint64_t tcps_rcvduppack;   /* duplicate-only packets received */
>   uint64_t tcps_rcvdupbyte;   /* duplicate-only bytes received */

This broke emulators/wine:

cc -c -I. -I. -I../../include -I../../include  -D__WINESRC__  -D_REENTRANT 
-fPIC -Wall -pipe -fno-strict-aliasing -Wdeclaration-after-statement 
-Wempty-body -Wignored-qualifiers -Wstrict-prototypes -Wtype-limits 
-Wwrite-strings -Wpointer-arith -fno-omit-frame-pointer -I/usr/local/include 
-O2 -pipe -march=athlon64  -fno-strict-aliasing  -o ipstats.o ipstats.c
ipstats.c:1109:92: error: no member named 'tcps_rcvmemdrop' in 'struct tcpstat';
  did you mean 'tcps_listendrop'?
  ...+ tcp_stat.tcps_rcvbadoff + tcp_stat.tcps_rcvmemdrop +
 tcp_stat.tcps_rcv...
  ^~~

I think this needs a __FreeBSD_version 1100020 and/or the addition
of a #define as a compatiblity crutch.

___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r266091 - head/share/man/man4

2014-05-14 Thread Warren Block
Author: wblock (doc committer)
Date: Wed May 14 21:45:16 2014
New Revision: 266091
URL: http://svnweb.freebsd.org/changeset/base/266091

Log:
  Connect vt.4 to the build.
  
  Reviewed by:  emaste

Modified:
  head/share/man/man4/Makefile

Modified: head/share/man/man4/Makefile
==
--- head/share/man/man4/MakefileWed May 14 20:49:10 2014
(r266090)
+++ head/share/man/man4/MakefileWed May 14 21:45:16 2014
(r266091)
@@ -565,6 +565,7 @@ MAN=aac.4 \
${_vmx.4} \
vpo.4 \
vr.4 \
+   vt.4 \
vte.4 \
${_vtnet.4} \
${_vxge.4} \
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r266092 - head/share/man/man4

2014-05-14 Thread Luiz Otavio O Souza
Author: loos
Date: Wed May 14 21:54:14 2014
New Revision: 266092
URL: http://svnweb.freebsd.org/changeset/base/266092

Log:
  gpioiic.4 and gpioled.4 will first appear in 10.1-RELEASE.

Modified:
  head/share/man/man4/gpioiic.4
  head/share/man/man4/gpioled.4

Modified: head/share/man/man4/gpioiic.4
==
--- head/share/man/man4/gpioiic.4   Wed May 14 21:45:16 2014
(r266091)
+++ head/share/man/man4/gpioiic.4   Wed May 14 21:54:14 2014
(r266092)
@@ -24,7 +24,7 @@
 .\"
 .\" $FreeBSD$
 .\"
-.Dd February 13, 2014
+.Dd May 14, 2014
 .Dt GPIOIIC 4
 .Os
 .Sh NAME
@@ -164,7 +164,7 @@ Optional, defaults to 1.
 The
 .Nm
 manual page first appeared in
-.Fx 11.0 .
+.Fx 10.1 .
 .Sh AUTHORS
 This
 manual page was written by

Modified: head/share/man/man4/gpioled.4
==
--- head/share/man/man4/gpioled.4   Wed May 14 21:45:16 2014
(r266091)
+++ head/share/man/man4/gpioled.4   Wed May 14 21:54:14 2014
(r266092)
@@ -24,7 +24,7 @@
 .\"
 .\" $FreeBSD$
 .\"
-.Dd February 13, 2014
+.Dd May 14, 2014
 .Dt GPIOLED 4
 .Os
 .Sh NAME
@@ -149,7 +149,7 @@ to create for
 The
 .Nm
 manual page first appeared in
-.Fx 11.0 .
+.Fx 10.1 .
 .Sh AUTHORS
 This
 manual page was written by
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r266093 - in head/sys/amd64: amd64 include

2014-05-14 Thread Neel Natu
Author: neel
Date: Wed May 14 22:24:09 2014
New Revision: 266093
URL: http://svnweb.freebsd.org/changeset/base/266093

Log:
  Increase the TSS limit by one byte. The processor requires an additional byte
  with all bits set to 1 beyond the I/O permission bitmap.
  
  Prior to this change accessing I/O ports [0xFFF8-0x] would trigger a
  #GP fault even though the I/O bitmap allowed access to those ports.
  
  For more details see section "I/O Permission Bit Map" in the Intel SDM, Vol 1.
  
  Reviewed by:  kib

Modified:
  head/sys/amd64/amd64/machdep.c
  head/sys/amd64/amd64/mp_machdep.c
  head/sys/amd64/amd64/sys_machdep.c
  head/sys/amd64/include/param.h

Modified: head/sys/amd64/amd64/machdep.c
==
--- head/sys/amd64/amd64/machdep.c  Wed May 14 21:54:14 2014
(r266092)
+++ head/sys/amd64/amd64/machdep.c  Wed May 14 22:24:09 2014
(r266093)
@@ -1147,7 +1147,7 @@ struct soft_segment_descriptor gdt_segs[
.ssd_gran = 1   },
 /* GPROC0_SEL  9 Proc 0 Tss Descriptor */
 {  .ssd_base = 0x0,
-   .ssd_limit = sizeof(struct amd64tss) + IOPAGES * PAGE_SIZE - 1,
+   .ssd_limit = sizeof(struct amd64tss) + IOPERM_BITMAP_SIZE - 1,
.ssd_type = SDT_SYSTSS,
.ssd_dpl = SEL_KPL,
.ssd_p = 1,
@@ -2003,8 +2003,7 @@ hammer_time(u_int64_t modulep, u_int64_t
common_tss[0].tss_ist2 = (long) np;
 
/* Set the IO permission bitmap (empty due to tss seg limit) */
-   common_tss[0].tss_iobase = sizeof(struct amd64tss) +
-   IOPAGES * PAGE_SIZE;
+   common_tss[0].tss_iobase = sizeof(struct amd64tss) + IOPERM_BITMAP_SIZE;
 
gsel_tss = GSEL(GPROC0_SEL, SEL_KPL);
ltr(gsel_tss);

Modified: head/sys/amd64/amd64/mp_machdep.c
==
--- head/sys/amd64/amd64/mp_machdep.c   Wed May 14 21:54:14 2014
(r266092)
+++ head/sys/amd64/amd64/mp_machdep.c   Wed May 14 22:24:09 2014
(r266093)
@@ -637,7 +637,7 @@ init_secondary(void)
common_tss[cpu] = common_tss[0];
common_tss[cpu].tss_rsp0 = 0;   /* not used until after switch */
common_tss[cpu].tss_iobase = sizeof(struct amd64tss) +
-   IOPAGES * PAGE_SIZE;
+   IOPERM_BITMAP_SIZE;
common_tss[cpu].tss_ist1 = (long)&doublefault_stack[PAGE_SIZE];
 
/* The NMI stack runs on IST2. */

Modified: head/sys/amd64/amd64/sys_machdep.c
==
--- head/sys/amd64/amd64/sys_machdep.c  Wed May 14 21:54:14 2014
(r266092)
+++ head/sys/amd64/amd64/sys_machdep.c  Wed May 14 22:24:09 2014
(r266093)
@@ -338,7 +338,6 @@ amd64_set_ioperm(td, uap)
char *iomap;
struct amd64tss *tssp;
struct system_segment_descriptor *tss_sd;
-   u_long *addr;
struct pcb *pcb;
 
if ((error = priv_check(td, PRIV_IO)) != 0)
@@ -361,9 +360,7 @@ amd64_set_ioperm(td, uap)
if (tssp == NULL)
return (ENOMEM);
iomap = (char *)&tssp[1];
-   addr = (u_long *)iomap;
-   for (i = 0; i < (ctob(IOPAGES) + 1) / sizeof(u_long); i++)
-   *addr++ = ~0;
+   memset(iomap, 0xff, IOPERM_BITMAP_SIZE);
critical_enter();
/* Takes care of tss_rsp0. */
memcpy(tssp, &common_tss[PCPU_GET(cpuid)],

Modified: head/sys/amd64/include/param.h
==
--- head/sys/amd64/include/param.h  Wed May 14 21:54:14 2014
(r266092)
+++ head/sys/amd64/include/param.h  Wed May 14 22:24:09 2014
(r266093)
@@ -120,6 +120,12 @@
 #defineMAXPAGESIZES3   /* maximum number of supported page 
sizes */
 
 #define IOPAGES2   /* pages of i/o permission bitmap */
+/*
+ * I/O permission bitmap has a bit for each I/O port plus an additional
+ * byte at the end with all bits set. See section "I/O Permission Bit Map"
+ * in the Intel SDM for more details.
+ */
+#defineIOPERM_BITMAP_SIZE  (IOPAGES * PAGE_SIZE + 1)
 
 #ifndefKSTACK_PAGES
 #defineKSTACK_PAGES4   /* pages of kstack (with pcb) */
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r266103 - head/sys/cddl/dev/dtrace/x86

2014-05-14 Thread Peter Grehan
Author: grehan
Date: Thu May 15 01:06:27 2014
New Revision: 266103
URL: http://svnweb.freebsd.org/changeset/base/266103

Log:
  Update dis_tables.c to the latest Illumos version.
  
  This includes decodes of recent Intel instructions, in particular
  VT-x and related instructions. This allows the FBT provider to
  locate the exit points of routines that include these new
  instructions.
  
  Illumos issues:
   3414 Need a new word of AT_SUN_HWCAP bits
   3415 Add isainfo support for f16c and rdrand
   3416 Need disassembler support for rdrand and f16c
   3413 isainfo -v overflows 80 columns
   3417 mdb disassembler confuses rdtscp for invlpg
   1518 dis should support AMD SVM/AMD-V/Pacifica instructions
   1096 i386 disassembler should understand complex nops
   1362 add kvmstat for monitoring of KVM statistics
   1363 add vmregs[] variable to DTrace
   1364 need disassembler support for VMX instructions
   1365 mdb needs 16-bit disassembler support
  
  This corresponds to Illumos-gate (github) version
  eb23829ff08a873c612ac45d191d559394b4b408
  
  Reviewed by:  markj
  MFC after:1 week

Modified:
  head/sys/cddl/dev/dtrace/x86/dis_tables.c

Modified: head/sys/cddl/dev/dtrace/x86/dis_tables.c
==
--- head/sys/cddl/dev/dtrace/x86/dis_tables.c   Thu May 15 00:52:17 2014
(r266102)
+++ head/sys/cddl/dev/dtrace/x86/dis_tables.c   Thu May 15 01:06:27 2014
(r266103)
@@ -21,6 +21,7 @@
  */
 /*
  * Copyright (c) 2003, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, Joyent, Inc. All rights reserved.
  */
 
 /*
@@ -104,16 +105,18 @@ enum {
Mv,
Mw,
M,  /* register or memory */
+   MG9,/* register or memory in group 9 (prefix optional) */
Mb, /* register or memory, always byte sized */
MO, /* memory only (no registers) */
PREF,
-   SWAPGS,
+   SWAPGS_RDTSCP,
MONITOR_MWAIT,
R,
RA,
SEG,
MR,
RM,
+   RM_66r, /* RM, but with a required 0x66 prefix */ 
IA,
MA,
SD,
@@ -228,7 +231,10 @@ enum {
VEX_RRi,/* VEX  mod_rm, imm8   -> mod_reg */
VEX_RM, /* VEX  mod_reg-> mod_rm */
VEX_RRM,/* VEX  VEX., mod_reg  -> mod_rm */
-   VEX_RMX /* VEX  VEX., mod_rm   -> mod_reg */
+   VEX_RMX,/* VEX  VEX., mod_rm   -> mod_reg */
+   VMx,/* vmcall/vmlaunch/vmresume/vmxoff */
+   VMxo,   /* VMx instruction with optional prefix */
+   SVM /* AMD SVM instructions */
 };
 
 /*
@@ -496,8 +502,8 @@ const instable_t dis_op0F00[8] = {
  */
 const instable_t dis_op0F01[8] = {
 
-/*  [0]  */TNSZ("sgdt",MO,6),  TNSZ("sidt",MONITOR_MWAIT,6), 
TNSZ("lgdt",XGETBV_XSETBV,6), TNSZ("lidt",MO,6),
-/*  [4]  */TNSZ("smsw",M,2),   INVALID,
TNSZ("lmsw",M,2),   TNS("invlpg",SWAPGS),
+/*  [0]  */TNSZ("sgdt",VMx,6), TNSZ("sidt",MONITOR_MWAIT,6),   
TNSZ("lgdt",XGETBV_XSETBV,6),   TNSZ("lidt",SVM,6),
+/*  [4]  */TNSZ("smsw",M,2),   INVALID,
TNSZ("lmsw",M,2),   TNS("invlpg",SWAPGS_RDTSCP),
 };
 
 /*
@@ -528,15 +534,44 @@ const instable_t dis_op0FBA[8] = {
 };
 
 /*
  * Decode table for 0x0FC7 opcode
  */
 
 const instable_t dis_op0FC7[8] = {
 
 /*  [0]  */INVALID,TNS("cmpxchg8b",M), INVALID,
INVALID,
-/*  [4]  */INVALID,INVALID,INVALID,
 INVALID,
+/*  [4]  */INVALID,INVALID,
TNS("vmptrld",MG9), TNS("vmptrst",MG9),
 };
 
+/*
+ * Decode table for 0x0FC7 opcode (group 9) mode 3
+ */
+
+const instable_t dis_op0FC7m3[8] = {
+
+/*  [0]  */INVALID,INVALID,INVALID,
INVALID,
+/*  [4]  */INVALID,INVALID,TNS("rdrand",MG9),  
INVALID,
+};
+
+/*
+ * Decode table for 0x0FC7 opcode with 0x66 prefix
+ */
+
+const instable_t dis_op660FC7[8] = {
+
+/*  [0]  */INVALID,INVALID,INVALID,
INVALID,
+/*  [4]  */INVALID,INVALID,
TNS("vmclear",M),   INVALID,
+};
+
+/*
+ * Decode table for 0x0FC7 opcode with 0xF3 prefix
+ */
+
+const instable_t dis_opF30FC7[8] = {
+
+/*  [0]  */INVALID,INVALID,INVALID,
INVALID,
+/*  [4]  */INVALID,INVALID,TNS("vmxon",M), 
INVALID,
+};
 
 /*
  * Decode table for 0x0FC8 opcode -- 486 bswap instruction
@@ -1147,7 +1182,7 @@ const instable_t dis_op0F38[256] = {
 /*  [78]  */   INVALID,INVALID,INVAL
@@ -528,15 +534,44 @@ const instable_t dis_op0FBA[8] = {
 
 /*
- * Decode table for 0x0FC7 opcode
+ * Decode table for 0x0FC7 opcode (group 9)
  */
 

svn commit: r266104 - head/usr.bin/bmake

2014-05-14 Thread Warner Losh
Author: imp
Date: Thu May 15 01:27:24 2014
New Revision: 266104
URL: http://svnweb.freebsd.org/changeset/base/266104

Log:
  Undo changes to the generated Makefile. Move tests directory to proper
  location, including updating the test to work in the more-fragile
  fmake -> bmake bootstrap environment.

Modified:
  head/usr.bin/bmake/Makefile
  head/usr.bin/bmake/Makefile.inc

Modified: head/usr.bin/bmake/Makefile
==